wtd.sd: Calculate a weighted standard deviation
Description
Used to weight deviations among ensembled model preditions
Usage
wtd.sd(x, w = NULL, na.rm = FALSE)
Arguments
w
a vector of weights equal to length of x
na.rm
a logical indicating how to handle missing values, default = FALSE